#!/usr/local/bin/perl
#
# Copyright (C) 2003,2004 Alexandre Dulaunoy <adulau@foo.be>
#
# This program is  free software; you can redistribute  it and/or modify
# it under the  terms of the GNU General Public  License as published by
# the Free Software Foundation; either  version 2 of the License, or (at
# your option) any later version.
#
# This program  is distributed in the  hope that it will  be useful, but
# WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
# MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
# General Public License for more details.
#
# You  should have received  a copy  of the  GNU General  Public License
# along  with  this  program;  if   not,  write  to  the  Free  Software
# Foundation, Inc., 59 Temple Place  - Suite 330, Boston, MA 02111-1307,
# USA.
#
# This software is a sample application to demonstrate the use of MQS.
#
# $Id: pushpolicy.pl,v 1.1 2004/12/29 11:06:32 adulau Exp $

use RPC::XML::Client;
use Data::Dumper;
use Getopt::Long;
use Digest::SHA1 qw(sha1_hex);
$| = 1;

my $version   = "0.0.1";
my $copyright =
"Copyright (C) 2003,2004 Alexandre Dulaunoy <adulau\@foo.be> and released under the GNU General Public License.";

my $result = GetOptions(
    "mqsurl=s" => \$mqsurl,
    "file=s"   => \$file,
    "auth=s"   => \$auth,
    "target=s" => \$target
);

if (   !( defined($mqsurl) )
    || !( defined($file) )
    || !( defined($auth) )
    || !( defined($target) ) )
{
    print "pushpolicy.pl $version usage :\n";
    print "\t--mqsurl <mqsurl> (e.g. https://127.0.0.1:9001/)\n";
    print "\t--file <filename> (e.g. pf-20040910.txt)\n";
    print
      "\t--auth <mqsauthstring> (e.g. auth:simple:test:anotherbadsamplekey)\n";
    print
"\t--target <targetofthepolicy> (e.g. fw1-external) This is the queue name dedicated to the target.\n\t The target can be a virtual queue with multiple real queues behind.\n";
    print "\n$copyright\n";
    exit(-1);
}

my $client = new RPC::XML::Client $mqsurl;

open( FILEX, "$file" ) or die "Unable to open file $file.";
my $policy;

while (<FILEX>) {
    $policy .= $_;
}

close(FILEX);

my $filedigest   = sha1_hex($policy);
my $policystring = $target . ";" . $file . ";" . $filedigest . "\n";
my $fullpolicy   = $policystring . $policy . "\n+++";

#print $fullpolicy;

chomp($policystring);

print "Submit policy $policystring --";
my $req =
  RPC::XML::request->new( 'mqs.SubmitMessage', $auth, $fullpolicy, $target, '',
    '-1' );
my $res   = $client->send_request($req);
my $value = $res->value;
if ( $value eq "1" ) {
    print "with success\n";
}
else {
    print "with error(s)\n";
    print Dumper( \$value );
}

